[![DOI](https://zenodo.org/badge/136149692.svg)](https://zenodo.org/badge/latestdoi/136149692)
[![CircleCI docs](https://circleci.com/gh/sappelhoff/eeg_positions/tree/main.svg?style=shield)](https://circleci.com/gh/sappelhoff/eeg_positions/tree/main)
[![Python build and test and deploy](https://github.com/sappelhoff/eeg_positions/workflows/Python%20build%20and%20test%20and%20deploy/badge.svg)](https://github.com/sappelhoff/eeg_positions/actions?query=workflow%3A%22Python+build+and+test+and+deploy%22)
[![Coverage](https://codecov.io/gh/sappelhoff/eeg_positions/branch/main/graph/badge.svg)](https://codecov.io/gh/sappelhoff/eeg_positions)
[![Latest PyPI release](https://img.shields.io/pypi/v/eeg_positions.svg)](https://pypi.org/project/eeg_positions/)


# eeg_positions

Compute and plot standard EEG electrode positions.

Please see the [**Documentation**](https://stefanappelhoff.com/eeg_positions/).

# Quickstart

There are two common ways to make use of this repository:

1. Go to the `data/` directory and download the EEG electrode position files you need
   (see the [README](https://github.com/sappelhoff/eeg_positions/tree/main/data) there).

1. Use `eeg_positions` as a Python package (install through `pip install eeg_positions`),
   and then obtain the EEG electrode positions through the `get_elec_coords` function.
   See the [Examples](https://stefanappelhoff.com/eeg_positions/auto_examples/index.html)
   and [API documentation](https://stefanappelhoff.com/eeg_positions/api.html).

# Cite

If you find this repository useful and want to cite it in your work, please go
to the [Zenodo record](https://doi.org/10.5281/zenodo.3718568) and obtain the
appropriate citation from the *"Cite as"* section there.

